@@ -5,7 +5,7 @@ package MooseX::Types::DateTime;
 use strict;
 use warnings;
 
-our $VERSION = "0.03";
+our $VERSION = "0.04";
 
 use DateTime ();
 use DateTime::Locale ();
@@ -186,6 +186,10 @@ Delegates to L<DateTime::TimeZone/new> with the string as the C<name> argument.
 
 =back
 
+=back
+
+=back
+
 =head1 SEE ALSO
 
 L<MooseX::Types::DateTimeX>
@@ -194,8 +198,8 @@ L<DateTime>, L<DateTimeX::Easy>
 
 =head1 VERSION CONTROL
 
-L<http://code2.0beta.co.uk/moose/svn/MooseX-Types-DateTime/trunk>. Ask on
-#moose for commit bits.
+This module is maintained using git. You can get the latest version from
+L<git://github.com/nothingmuch/moosex-types-datetime.git>.
 
 =head1 AUTHOR
 
